@@ -1097,7 +1097,8 @@ def shiftarrays_accum(Data_array, n, dimensions=1, diags=0):
         return shift_zero, allleft, allright
 
 def LocalMaxima_from_thresholdarray(Data, IntensityThreshold=400, rois=None, framedim=None,
-                                                                                    verbose=False):
+                                                                                    verbose=False,
+                                                                                    outputIpixmax=False):
     r"""
     return center of mass of each blobs composes by pixels above IntensityThreshold
 
@@ -1126,7 +1127,6 @@ def LocalMaxima_from_thresholdarray(Data, IntensityThreshold=400, rois=None, fra
                 print('min intensity in dataroi', np.amin(dataroi))
                 print('IntensityThreshold', IntensityThreshold)
 
-
             # other way equivalent
             # print("framedim in LocalMaxima_from_thresholdarray", framedim)
             # framedim = framedim[1], framedim[0]
@@ -1181,15 +1181,25 @@ def LocalMaxima_from_thresholdarray(Data, IntensityThreshold=400, rois=None, fra
         if nf == 0:
             return None
 
-        meanpos = np.array(ndimage.measurements.maximum_position(Data, ll, np.arange(1, nf + 1)),
-            dtype=float)
+        meanpos = np.array(ndimage.measurements.maximum_position(Data, ll, np.arange(1, nf + 1)))
 
-        if len(np.shape(meanpos)) > 1:
+        if len(np.shape(meanpos)) > 1:  # more than 1 peak
             meanpos = np.fliplr(meanpos)
-        else:
+        else:  # found a single peak
             meanpos = np.roll(meanpos, 1)
 
-    return meanpos
+    if outputIpixmax:
+        if len(np.shape(meanpos)) > 1:
+            print('meanpos' ,meanpos)
+            JJ, II = meanpos.T
+            Ipixmax = Data[II, JJ]
+            print('Ipixmax', Ipixmax)
+        else:
+            meanpos, Data[meanpos[1], meanpos[0]]
+        return meanpos, Ipixmax
+
+    else:
+        return meanpos
 
 
 def localmaxima(DataArray, n, diags=1, verbose=0):
@@ -1327,7 +1337,7 @@ def computefilteredimage(dataimage, bkg_image, CCDlabel, kernelsize=5, formulaex
     #     if framedim not in ((2048, 2048), [2048, 2048]):
     #         raise ValueError, "Background removal still implemented for non squared camera "
     # computing substraction on whole array
-    if CCDlabel in ("sCMOS", "sCMOS_fliplr"):
+    if CCDlabel in ("sCMOS", "sCMOS_16M","sCMOS_fliplr"):
         usemask = False
 
     if usemask:
